@@ -15,9 +15,11 @@ from anubis.scanners.netcraft import search_netcraft
 from anubis.scanners.nmap import scan_host
 from anubis.scanners.recursive import recursive_search
 from anubis.scanners.shodan import search_shodan
+from anubis.scanners.spyse import search_spyse
 from anubis.scanners.ssl import search_subject_alt_name
+from anubis.scanners.sublist3r import search_sublist3r
 from anubis.scanners.zonetransfer import dns_zonetransfer
-from anubis.utils.ColorPrint import ColorPrint
+from anubis.utils.color_print import ColorPrint
 from .base import Base
 
 
@@ -56,12 +58,11 @@ class Target(Base):
       self.options["TARGET"][i] = host
 
       try:
-        domain_str = socket.gethostbyname(host)
-        ColorPrint.green(f"Searching for subdomains for {domain_str} ({host})")
+        ip_str = socket.gethostbyname(host)
+        ColorPrint.green(f"Searching for subdomains for {ip_str} ({host})")
       except Exception as e:
         self.handle_exception(e,
                               "Error connecting to target! Make sure you spelled it correctly and it is a resolvable address")
-        raise e
 
   def run(self):
     # Retrieve IP of target and run initial configurations
@@ -72,6 +73,8 @@ class Target(Base):
       target = self.options["TARGET"][i]
       ColorPrint.green(f"Working on target: {target}")
       threads = [threading.Thread(target=dns_zonetransfer, args=(self, target)),
+                 threading.Thread(target=search_sublist3r,
+                                  args=(self, target)),
                  threading.Thread(target=subdomain_hackertarget,
                                   args=(self, target)),
                  threading.Thread(target=search_subject_alt_name,
@@ -80,6 +83,8 @@ class Target(Base):
                  threading.Thread(target=search_crtsh, args=(self, target)),
                  threading.Thread(target=search_dnsdumpster,
                                   args=(self, target)),
+                 threading.Thread(target=search_spyse,
+                                  args=(self, target)),
                  threading.Thread(target=search_anubisdb, args=(self, target))]
 
       # Additional options - shodan.io scan
@@ -115,9 +120,12 @@ class Target(Base):
         self.resolve_ips()
       else:
         for domain in self.dedupe:
-          ColorPrint.green(domain.strip())
+          cleaned_domain = domain.strip()
+          ColorPrint.green(cleaned_domain)
+          if self.options['--silent']:
+            sys.stdout.write(cleaned_domain + '\n', override=True)
 
-      if self.options["--send-to-anubis-db"]:
+      if not self.options["--dont-send-to-anubis-db"]:
         send_to_anubisdb(self, [target])
       # reset per domain
       self.domains = list()
@@ -129,11 +137,13 @@ class Target(Base):
         # Attempt to get IP
         resolved_ip = socket.gethostbyname(domain)
       except Exception as e:
-        self.handle_exception(e)
         # If getting IP fails, fallback to empty string
         resolved_ip = ""
       # TODO - Align domains and ips in stdout
       ColorPrint.green(domain + ": " + resolved_ip)
+      if self.options['--silent']:
+        sys.stdout.write(domain + '\n', override=True)
+
       if resolved_ip:
         unique_ips.add(resolved_ip)
     print("Found %s unique IPs" % len(unique_ips))
