@@ -1,9 +1,8 @@
 import socket
-from json import dumps
 
 import shodan
 
-from anubis.utils.ColorPrint import ColorPrint
+from anubis.utils.color_print import ColorPrint
 
 
 def search_shodan(self):
@@ -19,9 +18,6 @@ def search_shodan(self):
     try:
       results = api.host(socket.gethostbyname(self.options["TARGET"][i]))
 
-      if self.options["--verbose"]:
-        print(dumps(results, indent=2, sort_keys=True))
-
       print('Server Location: ' + str(results['city']) + ", " + str(
         results['country_code']) + ' - ' + str(results['postal_code']))
 
